@@ -20,15 +20,3 @@ class DomainWithHttp(DomainValidationError):
     Raised when the domain validation found http or https
     in the domain input.
     """
-
-
-class FileError(Exception):
-
-    def __init__(self, message):
-        super().__init__(message)
-
-
-class NotSupportedFileFormat(FileError):
-    """
-    Raised when the CLI found a non supported file format.
-    """
