@@ -7,15 +7,18 @@ from rdap.commands.history.utils import (
 )
 from rdap.common.utils import (
     format_domain_output,
+    load_file_data,
 )
 from rdap.common.constants import (
     MessageColors,
 )
+from rdap.common.save import Save
+
 
 @click.group(name="history", invoke_without_command=True)
 @click.pass_context
 def history(ctx):
-    """ Returns a table with the history of the last searches. """
+    """Returns a table with the history of the last searches."""
 
     if ctx.invoked_subcommand is None:
         generate_table()
@@ -29,14 +32,12 @@ def detail(id):
     output = get_record(id)
     if output:
         message = format_domain_output(output)
-        click.echo(
-            message
-        )
+        click.echo(message)
 
 
 @history.command(name="clear")
 def clear():
-    """ Clean history. """
+    """Clean history."""
 
     try:
         os.remove(CACHE_FILE_PATH)
@@ -48,7 +49,7 @@ def clear():
                 bold=True,
             )
         )
-    
+
     click.echo(
         click.style(
             "[DONE] - History was cleaned.",
@@ -56,3 +57,22 @@ def clear():
             bold=True,
         )
     )
+
+
+@history.command(name="download")
+@click.argument("filename")
+def download(filename):
+    """Download the history into a file."""
+
+    try:
+        _history = load_file_data(CACHE_FILE_PATH)
+    except FileNotFoundError:
+        return click.echo(
+            click.style(
+                "[INFO] - Nothing to download.",
+                fg=MessageColors.YELLOW,
+                bold=True,
+            )
+        )
+
+    Save().save_harvest(filename, _history)
